/*
 * common.c:
 *   by uratan! 2008.9.4
 */
#include "common.h"
#include "LPC214x.h"

/*
 * Initialize Serial Interface UART0
 */
void cm_init_serial0(u_long baudrate)
{
	u_long Fdiv;

	PINSEL0 |= 0x00000005;		/* Enable RxD0 and TxD0 */

	U0IER = 0x00;			/* do not use interrupts */

	U0LCR = 0x80;			/* DLAB=1 */
	U0FDR = 0x10;			/* do not use Fractional Divider */
	Fdiv = (Fpclk / 16) / baudrate;		/* calc division from baudrate */
	U0DLM = Fdiv / 256;
	U0DLL = Fdiv % 256;
	U0LCR = 0x03;			/* DLAB=0, 8bits, no-parity, 1stopbit */

	U0FCR = 0x00;			/* do not use FIFO (inhibited by datasheet!) */
}

/*
 * Write character to Serial Port 0
 */
void cm_putchar(int ch)
{
	/*
	 * wait for the buffer empty
	 */
	while(!(U0LSR & 0x20))
		;

	U0THR = ch;
	return;
}

/*
 * Read character from Serial Port
 */
int cm_keyin(void)
{
	if(U0LSR & 0x01) {
		return(U0RBR);	/* something has come */
	}

	return -1;		/* nothing has come */
}

/*
 * wait until something will come
 */
u_char cm_getchar(void)
{
	int i;

	while(1) {
		i = cm_keyin();
		if(i != -1)
			break;		/* something arrived */
	}
	return(i);
}
